import asyncio
import json
import sys
import threading
import time

import websocket

Version = '1.0'
# 常量
SUCCESS = 1
FAILED_WARNING = 2
FAILED_ERROR = 3


# sdk底层核心
class Core:
    ws = None
    asyncEvects = {}  # 异步事件
    resultEvents = {}  # 异步结果
    eventId = 0  # 等待事件id
    loop = None

    def __init__(self):
        self.loop = asyncio.get_event_loop()
        self.loop.run_until_complete(self.init())

    def om_open(self, ws):
        print('连接虚仿端成功')
        self.sendmsg(json.dumps({'event_id': 0, 'type': 'checkSdk', 'data': Version}))

    # 定义一个用来接收监听数据的方法
    def on_message(self, ws, message: str):
        # print("监听到消息,内容如下：" + message)
        obj = json.loads(message)
        id = obj['event_id']
        if id == None:
            print("主动消息:" + obj['msg'])
        else:
            self.resultEvents[id] = obj
            self.loop.call_soon_threadsafe(lambda: self.call(id))

    def call(self, id: int):
        if id in self.asyncEvects.keys():
            self.asyncEvects[id].set()
            del self.asyncEvects[id]
        else:
            print('无此id' + str(id))

    # 定义一个用来处理错误的方法
    def on_error(self, ws, error):
        print("-----连接出现异常，异常信息如下-----")
        print(error)

    # 定义一个用来处理关闭连接的方法
    def on_close(self, ws, code, msg):
        print("-------连接已关闭，退出运行------")
        print(code)


    def sendmsg(self, msg: str):
        self.ws.send(msg)

    def run(self):
        time.sleep(1)
        # print('启动监听')
        self.ws.run_forever()

    async def init(self):
        print('初始化中...')
        self.ws = websocket.WebSocketApp("ws://127.0.0.1:10088/cxx",
                                         on_open=self.om_open,
                                         on_message=self.on_message,
                                         on_error=self.on_error,
                                         on_close=self.on_close,
                                         )

        self.eventId = 0
        self.asyncEvects[0] = asyncio.Event()

        thread = threading.Thread(target=self.run)
        thread.daemon = True
        thread.start()
        await self.asyncEvects[0].wait()
        print('sdk版本检查中...')
        obj = self.resultEvents[0]
        del self.resultEvents[0]
        # 检查sdk版本
        if obj['result'] == SUCCESS:
            print("sdk版本正确")

            # 场景初始化
            print('场景初始化中...')
            self.eventId = 1
            self.asyncEvects[1] = asyncio.Event()
            self.sendmsg(json.dumps({'event_id': 1, 'type': 'other', 'commond': 'init_scene'}))
            await self.asyncEvects[1].wait()
            obj2 = self.resultEvents[1]
            del self.resultEvents[1]
            if obj2['result'] == SUCCESS:
                print('场景初始化成功')
            else:
                print('场景初始化失败:' + obj2.get('msg'))
        else:
            print("sdk版本不匹配! 请更换版本，当前版本：" + Version)
            sys.exit()

    def do_wait_return(self, data: dict):
        """
        发送消息并等待Unity程序返回结果
        :param data:
        """
        result = self.loop.run_until_complete(self.send_wait_return(data))

        if result['result'] != FAILED_ERROR:
            # if result.get('msg') is not None:
            #     print(result.get('msg'))
            return result
        else:
            print(result.get('msg'))
            sys.exit()

    def do_immediately(self, data: dict):
        """
        发送消息不等待Unity程序返回结果
        :param data:
        :return:
        """
        asyncio.run(self.send_no_return(data))

    async def send_wait_return(self, data: dict):
        self.eventId += 1
        __id = self.eventId
        data['event_id'] = __id
        self.asyncEvects[__id] = asyncio.Event()
        self.sendmsg(json.dumps(data))
        # print('开始等待事件%s结束' % __id)
        await Core.asyncEvects[__id].wait()
        obj = self.resultEvents[__id]
        del self.resultEvents[__id]
        return obj

    async def send_no_return(self, data: dict):
        self.eventId += 1
        __id = self.eventId
        data['event_id'] = __id
        self.asyncEvects[__id] = asyncio.Event()
        self.sendmsg(json.dumps(data))


MyWS = Core()



import json
import time
import ict_agent.core
from ict_agent.core import MyWS


class audio:

    def __init__(self):
        pass

    def audio_load(self, filepath: str):
        """
        加载音频  (仅支持wav，mp3格式)
        :param filepath:文件路径
        :return: 返回成功：True或失败：False
        """
        # MyWS.do_immediately(
        #     {'type': 'other', 'commond': 'audio_load', 'file_name': file_name})

        result =MyWS.do_wait_return( {'type': 'other', 'commond': 'audio_load', 'filepath': filepath})
        if result['result'] == ict_agent.core.SUCCESS:
            return True
        else:
            print(result['msg'])
            return False

    def audio_play(self):
        """
        播放音频
        :return:
        """
        MyWS.do_immediately({'type': 'other', 'commond': 'audio_play'})
        return

    def audio_pause(self):
        """
        暂停音频播放
        :return:
        """
        MyWS.do_immediately({'type': 'other', 'commond': 'audio_pause'})
        return

    def audio_stop(self):
        """
        停止播放音频
        :return:
        """
        MyWS.do_immediately({'type': 'other', 'commond': 'audio_stop'})
        return

    def audio_set_volume(self,volume:float):
        """
        设置音量
        :param volume: 音量大小(0~1)
        :return:
        """
        MyWS.do_immediately({'type': 'other', 'commond': 'audio_set_volume','volume':volume})
        return


def screen_shot(isStep:bool, stepName:str=''):
    """
    截图
    :param isStep: False:整个任务截图，True:单个步骤截图
    :param stepName: 填写对应步骤名，用于对应步骤
    :return:
    """
    if isStep==True:
        if stepName=='':
            print('截图步骤时步骤名称不能为空')
            return

    MyWS.do_immediately({'type': 'other', 'commond': 'screen_shot','isStep':isStep,'stepName':stepName})
    return

def set_camera_mode(mode:str,center:[float,float,float]=None,radius:float=None,speed:float=None,high:float=None):
    """
    设置相机模式
    :param mode: 模式名：自由模式 或 环绕模式
    :param center: 环绕中点
    :param radius: 环绕半径
    :param speed: 环绕速度
    :return:
    """
    if mode=='自由模式':
        MyWS.do_immediately({'type': 'other', 'commond': 'set_camera_mode', 'mode': mode})
    elif mode=='环绕模式':
        if(center==None or radius==None or speed==None or high==None):
            print('环绕模式下，请设置其它参数')
        else:
            MyWS.do_immediately({'type': 'other', 'commond': 'set_camera_mode', 'mode': mode,'center': center,'radius': radius,'speed': speed,'high':high})
    else:
        print('请输入正确模式名称')
    return

def get_control_image():
    """
    获取当前场景可替换的所有照片
    :return: 返回照片名称数组 string[]
    """
    result=MyWS.do_wait_return({'type': 'other', 'commond': 'get_control_image'})
    if result['result'] == ict_agent.core.SUCCESS:
        return json.loads(result['msg'])
    else:
        print(result['msg'])
        return None

def set_control_image(bgName:str,filePath:str):
    """
    设置背景照片
    :param bgName: 照片名称
    :param filePath: 图片本地路径
    :return:True:设置成功，False:设置失败
    """
    result=MyWS.do_wait_return({'type': 'other', 'commond': 'set_control_image', 'name': bgName,'filePath':filePath})
    if result['result'] == ict_agent.core.SUCCESS:
        return True
    else:
        print("照片设置失败："+result['msg'])
        return False

def get_scene_objet():
    """
    获取可创建的场景元素物体
    :return:返回元素名称数组 string[]
    """
    result = MyWS.do_wait_return({'type': 'other', 'commond': 'get_scene_objet'})
    if result['result'] == ict_agent.core.SUCCESS:
        return json.loads(result['msg'])
    else:
        print(result['msg'])
        return None
def set_scene_objet(name:str,point: [float, float,float]=[0,0,0],rotate:[float,float,float]=[0,0,0]):
    """
    创建场景元素物体
    :param name:物体名
    :param point:坐标位置
    :param rotate:旋转角度
    :return:True:设置成功，False:设置失败
    """
    result = MyWS.do_wait_return({'type': 'other', 'commond': 'set_scene_objet', 'name': name, 'point': point,'rotate':rotate})
    if result['result'] == ict_agent.core.SUCCESS:
        return True
    else:
        print("场景元素设置失败："+result['msg'])
        return False





import ict_agent
from ict_agent.core import MyWS

Number = 0


# 机器人
class Robot:
    name = '阿尔法狗'
    number = 0
    breast_piece_info = '编号2210'  # 胸牌信息
    color = '#ff00ff'

    def __init__(self,point: [float, float]=[0,0],rotate:float=0):
        """
        初始化
        :param point:初始坐标点 默认[0,0]
        :param rotate: 初始角度 默认0
        """
        global Number
        Number += 1
        self.number = Number
        result =MyWS.do_wait_return({'type': 'jqr', 'commond': 'init_position', 'point': point, 'rotate': rotate, 'number': self.number})
        if result['result'] == ict_agent.core.SUCCESS:
            print(result['msg'])
            return
        else:
            print(result['msg'])
            return None

    def set_name(self, name: str):
        """
        设置机器人名称
        :param name:
        :return:
        """
        self.name = name
        MyWS.do_immediately({'type': 'jqr', 'commond': 'set_name', 'name': name, 'number': self.number})
        return

    def set_color(self, color: str):
        """
        设置机器人颜色
        :param color: 16进制颜色字符，如： #FFFFFF
        :return:
        """
        MyWS.do_immediately({'type': 'jqr', 'commond': 'set_color', 'color': color, 'number': self.number})
        return

    def servo_motor_control(self, servo_id: int, value: int):
        """
        舵机控制
        :param servo_id: 舵机id(1-18)
        :param value: 舵机值(0-1000)
        :return:
        """
        servo_id=int(servo_id)
        value=int(value)
        if (servo_id>=0 and servo_id<=18):
            if (value>=0 and value<=1000):
                MyWS.do_immediately({'type': 'jqr', 'commond': 'servo_motor_control', 'servo_id': servo_id, 'value': value,'number': self.number})
            else:
                print("舵机值设置错误：0-1000")
        else:
            print("舵机id设置错误:1-18")
        return

    def get_action_lab(self):
        """
        获取机器人所有动作
        :return:
        """
        result = MyWS.do_wait_return({'type': 'jqr', 'commond': 'get_action_lab', 'number': self.number})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']
        else:
            print(result['msg'])
            return None

    def play_action(self, action: str,loop_times=1, duration=0):
        """
        执行动作
        :param action:动作名称
        :param loop_times:动作循环次数 int,默认不重复
        :param duration:动作结束后等待时间秒 float,默认不等待
        :return:
        """
        MyWS.do_immediately({'type': 'jqr', 'commond': 'play_action', 'action': action, 'duration': duration, 'loop_times': loop_times,'number': self.number})
        return

    def get_speech_text(self):
        """
        开始语音识别，并获取语音识别结果
        :return:
        """
        result = MyWS.do_wait_return({'type': 'jqr', 'commond': 'get_speech_text', 'number': self.number})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']
        else:
            print(result['msg'])
            return None

    def speak(self, txt: str, tone: str = 'xiaofeng'):
        """
        文本转语音
        :param txt:要转换的字符串
        :param tone:播音员（xiaofeng,xiaoyan,aisjiuxu,aisxping,aisjinger,aisbabyxu）
        :return:
        """
        MyWS.do_immediately({'type': 'jqr', 'commond': 'speak', 'number': self.number, 'txt': txt, 'tone': tone,'speed': 1})
        return

    def define_action(self):
        """
        打开动作编辑面板
        :param action:
        :return:
        """
        result = MyWS.do_wait_return({'type': 'jqr', 'commond': 'define_action', 'number': self.number})
        if result['result'] == ict_agent.core.SUCCESS:
            print(result['msg'])
        return
    def open_colorDetect(self):
        """
        打开图像识别
        """
        MyWS.do_immediately({'type': 'jqr', 'commond': 'openColorDetect', 'number': self.number})
        return

    def stop_colorDetect(self):
        """
        停止图像识别
        """
        MyWS.do_immediately({'type': 'jqr', 'commond': 'stopColorDetect', 'number': self.number})
        return

    # def formation_control(self, point: [float, float], matrix_size: [int, int], matrix_direction: [float, float]):
    #     return

    def turn_left(self,angle:float,time:float =1,wait_for_return: bool = False):
        """
        左转
        :param time: 持续时间，不传默认为1秒
        :param wait_for_return: 是否阻塞等待，不传默认不阻塞
        """
        if wait_for_return:
            result =MyWS.do_wait_return({'type': 'jqr', 'commond': 'trun_left', 'number': self.number,'angle':angle,'time':time})
            if result['result'] == ict_agent.core.SUCCESS:
                return
        else:
            MyWS.do_immediately({'type': 'jqr', 'commond': 'trun_left', 'number': self.number,'angle':angle,'time':time})
        return

    def turn_right(self,angle:float,time:float =1,wait_for_return: bool = False):
        """
        右转
        :param time: 持续时间，不传默认为1秒
        :param wait_for_return: 是否阻塞等待，不传默认不阻塞
        """
        if wait_for_return:
            result =MyWS.do_wait_return({'type': 'jqr', 'commond': 'trun_right', 'number': self.number,'angle':angle,'time':time})
            if result['result'] == ict_agent.core.SUCCESS:
                return
        else:
            MyWS.do_immediately({'type': 'jqr', 'commond': 'trun_right', 'number': self.number,'angle':angle,'time':time})
        return



import math

def drawRound(centerPoint:[float,float,float],radius:float,numPoints:int):
    """
    计算圆形的轨迹(单无人机)
    :param centerPoint:圆心坐标点
    :param radius:半径
    :param numPoints:生成点的数量
    :return:返回list[float,float,float]
    """
    points=[]
    for i in  range(numPoints):
        angleInRadians=math.pi*2/numPoints*i
        x=radius*math.sin(angleInRadians)
        y=radius*math.cos(angleInRadians)
        points.append([x+centerPoint[0],y+centerPoint[1],0+centerPoint[2]])

    return  points


def drawElliptic(center:[float,float,float],radiusX:float,radiusY:float,detalangle:float):
    """
    计算椭圆的轨迹(单无人机)
    :param center: 中心点
    :param radiusX: x半径
    :param radiusY: y半径
    :param detalangle: 间隔角度
    :return:返回list[float,float,float]
    """
    points=[]
    angle=0
    while angle<=math.pi*2:
        x=center[0]+radiusX*math.sin(angle)
        y=center[1]-radiusY*math.cos(angle)
        points.append([x,y,center[2]])
        angle+=detalangle

    return  points


def drawSin(center:[float,float,float],A:float,pointNum:float,cycle:int):
    """
    计算sin轨迹(单无人机)
    :param center: 起点原点
    :param A: y轴系数
    :param pointNum: 一个周期内点的数量（不得小于5，点越多，形状越像）
    :param cycle: 周期数
    :return:返回list[float,float,float]
    """
    points=[]
    if pointNum<=5:
        print("一个周期点数不得小于5")
        return points

    x=0
    detal=2*math.pi/pointNum
    while x<=math.pi*2*cycle:
        y=math.sin(x)*A
        points.append([x+center[0], y+center[1], center[2]])
        x+=detal

    return  points

def drawCube(centerPoint:[float,float,float],length:float,wighth:float,high:float):
    """
    计算立方体轨迹(单无人机)
    :param centerPoint:立方体中心点
    :param length:长
    :param wighth:宽
    :param high:高
    :return:
    """
    points = [[0,0,0],
              [length,0,0],
              [length,high,0],
              [0,high,0],
              [0,0,0],
              [0,0,wighth],
              [length,0,wighth],
              [length,0,0],
              [length,high,0],
              [length,high,wighth],
              [length,0,wighth],
              [length,high,wighth],
              [0,high,wighth],
              [0,0,wighth],
              [0,high,wighth],
              [0,high,0]]

    # 中心点偏移矫正
    for i in points:
        i[0]+=(centerPoint[0]-length/2)
        i[1]+=(centerPoint[1]-high/2)
        i[2]+=(centerPoint[2]-wighth/2)

    return points

def drawSphere(centerPoint:[float,float,float],radius:float,numPoints:int):
    """
    计算球体轨迹(单无人机)
    :param centerPoint: 中心点
    :param radius: 半径
    :param numPoints: 一个圆的数量（建议设置为4的倍数）
    :return:
    """
    point2ds = []
    point3ds = []
    for i in range(numPoints+1):
        angleInRadians = math.pi * 2 / numPoints * i
        x = radius * math.sin(angleInRadians)
        y = radius * math.cos(angleInRadians)
        point2ds.append([x,y])

    # 第一个圆
    for p2d in point2ds:
        point3ds.append([p2d[0],p2d[1],0])
    # 第二个圆
    for p2d in point2ds:
        point3ds.append([0,p2d[1],p2d[0]])

    #1/4半圆
    for i in range(numPoints+1):
        angleInRadians = math.pi / 2 / numPoints * i
        x = radius * math.sin(angleInRadians)
        y = radius * math.cos(angleInRadians)
        point3ds.append([0,y,x])

    # 第三个圆
    for p2d in point2ds:
        point3ds.append([p2d[0],0,p2d[1]])

    # 中心点偏移矫正
    for i in point3ds:
        i[0]+=centerPoint[0]
        i[1]+=centerPoint[1]
        i[2]+=centerPoint[2]

    return point3ds

def drawCylinder(centerPoint:[float,float,float],radius:float,high:float,numPoints:int):
    """
    计算球体轨迹(单无人机)
    :param centerPoint: 中心点
    :param radius: 半径
    :param high: 高度
    :param numPoints: 一个圆的数量（建议设置为4的倍数）
    :return:
    """
    point2ds = []
    point3ds = []
    for i in range(numPoints+1):
        angleInRadians = math.pi * 2 / numPoints * i
        x = radius * math.sin(angleInRadians)
        y = radius * math.cos(angleInRadians)
        point2ds.append([x,y])

    # 第一个圆
    for p2d in point2ds:
        point3ds.append([p2d[0],0,p2d[1]])

    # 第二个圆
    for p2d in point2ds:
        point3ds.append([p2d[0],high,p2d[1]])

    # 1/4圆
    for i in range(numPoints+1):
        angleInRadians = math.pi / 2 / numPoints * i
        x = radius * math.sin(angleInRadians)
        y = radius * math.cos(angleInRadians)
        point3ds.append([x,high,y])

    # 下去
    point3ds.append([point3ds[-1][0],0,point3ds[-1][2]])

    # 2/4圆
    for i in range(numPoints+1):
        angleInRadians = math.pi / 2 / numPoints * i + math.pi / 2
        x = radius * math.sin(angleInRadians)
        y = radius * math.cos(angleInRadians)
        point3ds.append([x,0,y])

    # 上去
    point3ds.append([point3ds[-1][0], high, point3ds[-1][2]])

    # 3/4圆
    for i in range(numPoints+1):
        angleInRadians = math.pi / 2 / numPoints * i + math.pi
        x = radius * math.sin(angleInRadians)
        y = radius * math.cos(angleInRadians)
        point3ds.append([x,high,y])

    # 下去
    point3ds.append([point3ds[-1][0],0,point3ds[-1][2]])

    # 中心点偏移矫正
    for i in point3ds:
        i[0]+=(centerPoint[0])
        i[1]+=(centerPoint[1]-high/2)
        i[2]+=(centerPoint[2])

    return point3ds

def drawCone(centerPoint:[float,float,float],radius:float,high:float,numPoints:int):
    """
    计算球体轨迹(单无人机)
    :param centerPoint: 中心点
    :param radius: 半径
    :param high: 高度
    :param numPoints: 一个圆的数量（建议设置为4的倍数）
    :return:
    """
    point2ds = []
    point3ds = []
    for i in range(numPoints+1):
        angleInRadians = math.pi * 2 / numPoints * i
        x = radius * math.sin(angleInRadians)
        y = radius * math.cos(angleInRadians)
        point2ds.append([x,y])

    # 第一个圆
    for p2d in point2ds:
        point3ds.append([p2d[0],0,p2d[1]])

    # 顶点
    point3ds.append([0, high,0])

    # 退到1/4
    point3ds.append([radius,0,0])

    # 顶点
    point3ds.append([0, high,0])

    # 退到2/4
    point3ds.append([0,0,-radius])

    # 顶点
    point3ds.append([0, high,0])

    # 退到3/4
    point3ds.append([-radius,0,0])

    # 中心点偏移矫正
    for i in point3ds:
        i[0]+=(centerPoint[0])
        i[1]+=(centerPoint[1])
        i[2]+=(centerPoint[2])

    return point3ds

def drawSphere_complex(center:[float,float,float],radius :float,num_Sqr :int):
    """
    计算球面点集(多无人机)
    :param center: 中点坐标
    :param radius: 半径
    :param num_Sqr: 总点数，最终返回此数值的平方个点
    :return: 返回点集合list[float,float,float]，上限为1000个点
    """
    points=[]
    phi_values = [math.pi * i / (num_Sqr - 1) for i in range(num_Sqr)]
    theta_values = [2 * math.pi * i / num_Sqr for i in range(num_Sqr)]

    for phi in phi_values:
        for theta in theta_values:
            x = radius * math.sin(phi) * math.cos(theta)
            y = radius * math.sin(phi) * math.sin(theta)
            z = radius * math.cos(phi)
            points.append([x+center[0], y+center[1], z+center[2]])

    if len(points)>1000:
        print("请调小密度，为了保证性能，最多输出1000个点")
        return None
    else:
        return  points


import ict_agent.core
from ict_agent.core import MyWS

# 数字人
class DigtalHuman():
    name = '安琪拉'
    age = 18
    sex = False  # 性别 true：男 ，false：女
    build = []  # 体型
    complexion = []  # 肤色
    voice = []  # 声音
    volume = 1.0  # 音量
    appearance = []  # 容貌
    clothing_lab = ['西装男', '西装女', '古装男', '古装女']  # 服装
    expression = []  # 表情
    head_action = []  # 头部动作
    hand_action = []  # 手部动作
    Legsandtorso_action = []  # 腿和躯干动作
    default_action = []  # 默认动作无法定制

    def __init__(self):
        """

        """
        MyWS.do_wait_return({'type': 'szr', 'commond': 'init'})
        return

    # def init_man(self):
    #     return self

    def init_human(self, sex: str):
        """
        初始化数字人
        :param sex:性别Male，Female
        :return: self
        """

        result = MyWS.do_wait_return(self.__handle_result('init_human', {'sex': sex}))
        return self

    def set_name(self, name: str):
        """
        设置数字人名字
        :param name:名称
        :return: bool返回操作成功或失败
        """

        result = MyWS.do_wait_return(self.__handle_result('set_name', {'name': name}))
        return result['msg']

    def set_age(self, age: int):
        """
        设置数字人年龄
        :param age:年龄
        :return: bool返回操作成功或失败
        """

        result = MyWS.do_wait_return(self.__handle_result('set_age', {'age': age}))
        return result['msg']

    def get_sex(self):
        """
        获取数字人性别
        :return:返回性别
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_sex'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_sex(self, sex: str):
        """
        设置数字人性别
        :param sex:性别Male，Female
        :return: bool返回操作成功或失败
        """

        result = MyWS.do_wait_return(self.__handle_result('set_sex', {'sex': sex}))
        return result['msg']

    def get_somatotype(self):
        """
        获取体型列表
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_somatotype'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_somatotype(self, somatotype: str):
        """
        设置体型
        :param somatotype:体型
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_somatotype', {'somatotype': somatotype}))
        return result['msg']

    def set_volume(self, volume: int):
        """
        设置音量
        :param volume:音量
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_volume', {'volume': volume}))
        return result['msg']
        return

    def get_clothing(self):
        """
        获取服装列表
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_clothing'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_clothing(self, clothing: str):
        """
        设置服装
        :param clothing:服装
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_clothing', {'clothing': clothing}))
        return result['msg']

    def get_pants(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_pants'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_pants(self, pants: str):
        """

        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_pants', {'pants': pants}))
        return result['msg']

    def get_hairstyle(self):
        """
        获取发型列表
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_hairstyle'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_hairstyle(self, hairstyle: str):
        """
        设置发型
        :param hairstyle: 发型
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_hairstyle', {'hairstyle': hairstyle}))
        return result['msg']

    def get_face(self):
        """
        获取脸型列表
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_face'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_face(self, face: str):
        """
        设置脸型
        :return: face: 脸型
        """
        result = MyWS.do_wait_return(self.__handle_result('set_face', {'face': face}))
        return result['msg']

    def get_glasses(self):
        """
        获取眼镜列表
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_glasses'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_glasses(self, glasses: str):
        """
        设置眼镜
        :return: glasses : 眼镜
        """
        result = MyWS.do_wait_return(self.__handle_result('set_glasses', {'glasses': glasses}))
        return result['msg']

    def __handle_result(self, commond: str, parameters: dict = None):
        # for i in parameters:
        return {'type': 'szr', 'commond': commond, 'parameters': parameters}

    def get_head_action(self):
        """
        获取头部动作列表
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_head_action'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def get_hand_action(self):
            """
            获取手部动作列表
            :return:
            """
            result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_hand_action'})
            if result['result'] == ict_agent.core.SUCCESS:
                return result['msg']

    def get_legs_action(self):
            """
            获取腿部动作列表
            :return:
            """
            result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_legs_action'})
            if result['result'] == ict_agent.core.SUCCESS:
                return result['msg']

    def get_torso_action(self):
            """
            获取躯干动作列表
            :return:
            """
            result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_torso_action'})
            if result['result'] == ict_agent.core.SUCCESS:
                return result['msg']

    def get_emote_action(self):
            """
            获取表情动作列表
            :return:
            """
            result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_emote_action'})
            if result['result'] == ict_agent.core.SUCCESS:
                return result['msg']

    def set_head_action(self, action: [str], loop_times: int):
        """
        设置头部动作
        :param action:
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_head_action', {'action': action,'loop_times': loop_times}))
        return result['msg']

    def set_hand_action(self, action: [str], loop_times: int):
        """
        设置手部动作
        :param action:
        :param loop_times:
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_hand_action', {'action': action,'loop_times': loop_times}))
        return result['msg']

    def set_torso_action(self, action: [str], loop_times: int):
        """
        设置躯干动作
        :param action:
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_torso_action', {'action': action,'loop_times': loop_times}))
        return result['msg']

    def set_emote_action(self, emote: str):
        """
        设置表情动作
        :param action:
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_emote_action', {'emote': emote}))
        return result['msg']

    def get_skincolor(self):
        """
        获取肤色列表
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_skincolor'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_skincolor(self, skincolor: str):
        """
        设置肤色
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_skincolor', {'skincolor': skincolor}))
        return result['msg']

    def get_timbre(self):
        """
        获取音色列表
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_timbre'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_timbre(self, timbre: str):
        """
        设置音色
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_timbre', {'timbre': timbre}))
        return result['msg']

    def stop_audio(self):
        """
        停止音乐
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'stop_audio'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def play_text_content(self, content: str):
        """
        播报新闻稿
        :param content:
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('play_text_content', {'content': content}))
        return result['msg']

    def stop_text(self):
        """
        停止播报新闻稿
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'stop_text'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def get_speech_text(self):
        """
        开始语音识别，并获取语音识别结果
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_speech_text'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']
        else:
            print(result['msg'])
            return None

    def export_appearance(self):
        """
        导出外观参数
        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'export_appearance'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def get_audio_clip(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_audio_clip'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_audio_clip(self, audio: str):
        """

        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_audio_clip', {'audio': audio}))
        return result['msg']

    def play_audio(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'play_audio'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def pause_audio(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'pause_audio'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def unpause_audio(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'unpause_audio'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def stop_audio(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'stop_audio'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def get_text_asset(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'get_text_asset'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def set_text_asset(self, text_asset: str):
        """

        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('set_text_asset', {'text_asset': text_asset}))
        return result['msg']

    def play_text(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'play_text'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']

    def stop_text(self):
        """

        :return:
        """
        result = MyWS.do_wait_return({'type': 'szr', 'commond': 'stop_text'})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']


import time

import ict_agent.core
from ict_agent.core import MyWS
import ict_agent.Math as  Math

Number = 0
Time = time.strftime('%H:%M:%S', time.localtime(time.time()))


# 无人机
class UAV:
    # 编号
    number = 0
    # 名称
    name = ''
    # 无人机区域1、2颜色
    color_1 = ''
    color_2 = ''
    # 位置
    pos_x = 0
    pos_y = 0
    # 旋翼输出
    rotor_power = [0, 0, 0, 0]
    # 灯光颜色
    lighter_color = ''
    # 高度
    height = 0
    # 水平距离
    distance = 0
    # 姿态角
    attitude_angle = [0, 0, 0]
    # 水平速度
    horizontal_speed = 0
    # 垂直速度
    vertical_speed = 0

    # def __init__(self, point: [float, float]):
    #     """
    #     无人机构造函数
    #     :param point: 设置无人机生成位置
    #     """
    #     global Number
    #     Number += 1
    #     self.number = Number
    #     self.pos_x = point[0]
    #     self.pos_y = point[1]
    #     result = MyWS.doAwait({'type': 'wrj', 'commond': 'create', 'pos': point, 'number': self.number})
    #     if (result['result'] == ict_agent.core.SUCCESS):
    #         print('创建成功:' + str(self.number))

    def __init__(self):
        pass

    def init_position(self, point: [float, float]):
        """
        初始化无人机坐标
        :param point:
        :return:
        """
        global Number
        Number += 1
        self.number = Number
        self.pos_x = point[0]
        self.pos_y = point[1]
        result = MyWS.do_wait_return({'type': 'wrj', 'commond': 'init_position', 'pos': point, 'number': self.number})
        if result['result'] == ict_agent.core.SUCCESS:
            print('【%s UAV:%s】创建成功，事件%s结束' % (Time, self.number, result['event_id']))
        return self

    def set_name(self, name: str):
        """
        设置无人机名称
        :param name:无人机名称
        :return:
        """
        self.name = name
        # result = MyWS.do_wait_return({'type': 'wrj', 'commond': 'set_name', 'name': name, 'number': self.number})
        # if result['result'] == ict_agent.core.SUCCESS:
        #     print('【%s UAV:%s】创建成功，事件%s结束' % (Time, self.number, result['event_id']))
        MyWS.do_immediately({'type': 'wrj', 'commond': 'set_name', 'name': name, 'number': self.number})
        return

    def set_color(self, color_1: str = '#FFFFFF', color_2: str = '#000000'):
        """
        设置无人机颜色
        :param color_1:无人机模型区域1颜色
        :param color_2:无人机模型区域2颜色
        :return:
        """
        self.color_1 = color_1
        self.color_2 = color_2
        MyWS.do_immediately(
            {'type': 'wrj', 'commond': 'set_color', 'color_1': color_1, 'color_2': color_2, 'number': self.number})
        return

    def start_engine(self):
        """
        启动引擎
        :return:
        """
        # result = MyWS.do_wait_return({'type': 'wrj', 'commond': 'start_engine', 'number': self.number})
        # if result['result'] == ict_agent.core.SUCCESS:
        #     print('【%s UAV:%s】启动成功，事件%s结束' % (Time, self.number, result['event_id']))
        MyWS.do_immediately({'type': 'wrj', 'commond': 'start_engine', 'number': self.number})
        return

    def shut_down_engine(self):
        """
        关闭引擎
        :return:
        """
        # result = MyWS.do_wait_return({'type': 'wrj', 'commond': 'shut_down_engine', 'number': self.number})
        # if result['result'] == ict_agent.core.SUCCESS:
        #     print('【%s UAV:%s】关闭成功，事件%s结束' % (Time, self.number, result['event_id']))
        MyWS.do_immediately({'type': 'wrj', 'commond': 'shut_down_engine', 'number': self.number})
        return

    def set_rotor_power(self, power: [float, float, float, float]):
        """
        设置无人机各旋翼输出
        :param power:
        :return:
        """
        self.rotor_power = power
        MyWS.do_immediately(self.__handle_result('set_rotor_power', {'power': power}))
        return

    def open_lighter(self, color: str, intensity: float = 1, halo: float = 1):
        """
        打开无人机灯光
        :param color: 灯光颜色
        :param intensity: 灯光强度
        :param halo: 光晕强度
        :return:
        """
        self.lighter_color = color
        MyWS.do_immediately(
            self.__handle_result('open_lighter', {'color': color, 'intensity': intensity, 'halo': halo}))
        return

    def close_lighter(self):
        """
        关闭无人机灯光
        :return:
        """
        MyWS.do_immediately(self.__handle_result('close_lighter'))
        return

    def get_current_height(self):
        """
        获取无人机当前高度
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('get_current_height'))
        if result['result'] == ict_agent.core.SUCCESS:
            print(result['msg'])
        return

    def get_current_attitude_angle(self):
        """
        获取无人机当前姿态角
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('get_current_attitude_angle'))
        if result['result'] == ict_agent.core.SUCCESS:
            print(result['msg'])
        return

    def get_current_distance(self):
        """
        当前无人机与返航点的水平方向距离
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('get_current_distance'))
        if result['result'] == ict_agent.core.SUCCESS:
            print(result['msg'])
        return

    def get_current_horizontal_speed(self):
        """
        当前无人机的水平方向速度
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('get_current_horizontal_speed'))
        if result['result'] == ict_agent.core.SUCCESS:
            print(result['msg'])
        return

    def get_current_vertical_speed(self):
        """
        当前无人机的垂直速度
        :return:
        """
        result = MyWS.do_wait_return(self.__handle_result('get_current_vertical_speed'))
        if result['result'] == ict_agent.core.SUCCESS:
            print(result['msg'])
        return

    def open_hd(self):
        """
        打开高清图传
        :return:
        """
        MyWS.do_immediately(self.__handle_result('open_hd'))
        return

    def close_hd(self):
        """
        关闭高清图传
        :return:
        """
        MyWS.do_immediately(self.__handle_result('close_hd'))
        return

    def fly_by_3d_direction(self, direction: [float, float, float], speed: float, duration: float):
        """
        以给定速度朝方向飞行多长时间
        :param direction: 三维飞行方向，X：前后，Y：左右，Z：上下
        :param speed: 飞行速度（米/秒）
        :param duration: 飞行时间（秒）
        :return:
        """
        MyWS.do_immediately(
            {'type': 'wrj', 'commond': 'fly_by_3d_direction', 'number': self.number, 'direction': direction,
             'speed': speed,
             'time': duration}
        )
        return

    def fly_to_point_by_time(self, direction: [float, float, float], duration: float, wait_for_return: bool = False):
        """
        在规定时间内飞至指定位置
        :param direction: 目标点坐标
        :param duration: 固定时间（秒）
        :param wait_for_return: 是否等待Unity程序返回结果
        :return:
        """
        if wait_for_return:
            result = MyWS.do_wait_return({'type': 'wrj', 'commond': 'fly_to_point_by_time', 'number': self.number, 'direction': direction,'duration': duration})
            if result['result'] == ict_agent.core.SUCCESS:
                print('【%s UAV:%s】飞行完成，事件%s结束' % (Time, self.number, result['event_id']))
        else:
            MyWS.do_immediately({'type': 'wrj', 'commond': 'fly_to_point_by_time', 'number': self.number, 'direction': direction,'duration': duration})

        return

    def fly_to_point_by_speed(self, direction: [float, float, float], speed: float,wait_for_return: bool = False):
        """
        在固定速度的情况下飞至指定位置
        :param direction: 目标点坐标 [float, float, float]
        :param speed: 飞行速度（米/秒）
        :return:
        """
        if wait_for_return:
            result=MyWS.do_wait_return({'type': 'wrj', 'commond': 'fly_to_point_by_speed', 'number': self.number, 'direction': direction,'duration': speed})
            if result['result'] == ict_agent.core.SUCCESS:
                print('【%s UAV:%s】飞行完成，事件%s结束' % (Time, self.number, result['event_id']))
        else:
            MyWS.do_immediately({'type': 'wrj', 'commond': 'fly_to_point_by_speed', 'number': self.number, 'direction': direction,'duration': speed})

        return

    def hovering(self):
        """
        无人机悬停
        :return:
        """
        MyWS.do_immediately(self.__handle_result('hovering'))
        return

    def open_trail_render(self, color: str = '#FFFFFF', thickness: float = 0.1):
        """
        打开无人机飞行轨迹
        :param color: 轨迹颜色
        :param thickness: 轨迹厚度，[0.1-1]
        :return:
        """
        MyWS.do_immediately(
            self.__handle_result('open_trail_render', {'color': color, 'thickness': thickness})
        )
        return

    def close_trail_render(self):
        """
        关闭无人机飞行轨迹
        :return:
        """
        MyWS.do_immediately(
            {'type': 'wrj', 'commond': 'close_trail_render', 'number': self.number}
        )
        return

    def enable_obstacle_avoidance(self):
        """
        启用避障功能
        :return:
        """
        MyWS.do_immediately({'type': 'wrj', 'commond': 'enable_obstacle_avoidance', 'number': self.number})
        return

    def disable_obstacle_avoidance(self):
        """
        关闭避障功能
        :return:
        """
        MyWS.do_immediately({'type': 'wrj', 'commond': 'disable_obstacle_avoidance', 'number': self.number})
        return

    def __handle_result(self, commond: str, parameters: dict = None):
        # for i in parameters:

        return {'type': 'wrj', 'commond': commond, 'number': self.number, 'parameters': parameters}

    def formation_control(self, formation_data: [str], wait_for_return: bool = False):
        """
        编队飞行
        :param formation_data: 编队数据
        :param wait_for_return: 是否等待程序执行结束
        :return:
        """
        data = {'type': 'wrj', 'commond': 'formation_control', 'formation_data': formation_data,
                'wait_for_return': wait_for_return}
        if wait_for_return:
            result = MyWS.do_wait_return(data)
            if result['result'] == ict_agent.core.SUCCESS:
                return
        else:
            MyWS.do_immediately(data)
            return

    def time_set(self, t_time: str = '昼'):
        """
        场景昼夜设置
        :param t_time:时间：昼、夜
        :return:
        """
        data = {'type': 'wrj', 'commond': 'time_set', 't_time': t_time}
        result = MyWS.do_wait_return(data)
        if result['result'] == ict_agent.core.SUCCESS:
            print('设置成功')
            return
        else:
            print('设置失败')
            return

    def open_real_camera(self):
        """
        打开相机
        :return:
        """
        MyWS.do_immediately(self.__handle_result('open_real_camera'))

    def close_real_camera(self):
        """
        关闭相机
        :return:
        """
        MyWS.do_immediately(self.__handle_result('close_real_camera'))
    def get_speech_text(self):
        """
        开始语音识别，并获取语音识别结果
        :return:
        """
        result = MyWS.do_wait_return({'type': 'wrj', 'commond': 'get_speech_text', 'number': self.number})
        if result['result'] == ict_agent.core.SUCCESS:
            return result['msg']
        else:
            print(result['msg'])
            return None


    def open_collider(self):
        """
        打开碰撞
        :return:
        """
        MyWS.do_immediately({'type': 'wrj', 'commond': 'openCollider', 'number': self.number})
        return

    def close_collider(self):
        """
        关闭碰撞
        :return:
        """
        MyWS.do_immediately({'type': 'wrj', 'commond': 'close_collider', 'number': self.number})
        return

    def draw_fly_Cube(self,center:[float,float,float],length:float, wighth:float,high:float,time:float,color: str = '#FFFFFF',alpha:float=1, thickness: float = 0.1,wait_for_return: bool = False):
        """
        画立方体(单人机)
        :param center: 中心点
        :param length: 长
        :param wighth: 宽
        :param high: 高
        :param time: 绘制时长
        :param color: 颜色
        :param alpha: 透明度 (0-1)
        :param thickness: 线粗细
        :param wait_for_return: 是否阻塞，等待执绘制完成
        :return:
        """
        points=Math.drawCube(center,length,wighth,high)
        if wait_for_return:
            result=MyWS.do_wait_return({'type': 'wrj', 'commond': 'draw_fly_Cube', 'number': self.number, 'points': points, 'length': length,'wighth': wighth, 'high': high, 'color': color,'alpha':alpha, 'thickness': thickness, 'time': time,'center': center})
            if result['result'] == ict_agent.core.SUCCESS:
                print("立方体绘制完成")
        else:
            MyWS.do_immediately({'type': 'wrj', 'commond': 'draw_fly_Cube', 'number': self.number,'points':points,'length':length,'wighth':wighth,'high':high,'color':color,'alpha':alpha,'thickness':thickness,'time':time,'center':center})
        return

    def draw_fly_Sphere(self,center:[float,float,float],radius:float,numPoints:int,time:float,color: str = '#FFFFFF',alpha:float=1, thickness: float = 0.1,wait_for_return: bool = False):
        """
        画球体(单无人机)
        :param center: 中心点
        :param radius: 球半径
        :param numPoints: 一个圆的点数量（建议设置为4的倍数）
        :param time:绘制时长
        :param color: 颜色
        :param alpha: 透明度 (0-1)
        :param thickness: 线粗细
        :param wait_for_return: 是否阻塞，等待执绘制完成
        :return:
        """
        points=Math.drawSphere(center,radius,numPoints)
        if wait_for_return:
            result=MyWS.do_wait_return({'type': 'wrj', 'commond': 'draw_fly_Sphere', 'number': self.number, 'points': points, 'radius': radius,'color': color,'alpha':alpha, 'thickness': thickness, 'time': time, 'center': center})
            if result['result'] == ict_agent.core.SUCCESS:
                print("球体绘制完成")
        else:
            MyWS.do_immediately({'type': 'wrj', 'commond': 'draw_fly_Sphere', 'number': self.number,'points':points,'radius':radius,'color':color,'alpha':alpha,'thickness':thickness,'time':time,'center':center})
        return

    def draw_fly_Cylinder(self,center:[float,float,float],radius:float,high:float,numPoints:int,time:float,color: str = '#FFFFFF',alpha:float=1, thickness: float = 0.1,wait_for_return: bool = False):
        """
        画圆柱体(单无人机)
        :param center: 中心点
        :param radius: 圆柱半径
        :param high: 圆柱高度
        :param numPoints: 圆的点数量（建议设置为4的倍数）
        :param time:绘制时长
        :param color: 颜色
        :param alpha: 透明度 (0-1)
        :param thickness: 线粗细
        :param wait_for_return: 是否阻塞，等待执绘制完成
        :return:
        """
        points=Math.drawCylinder(center,radius,high,numPoints)
        if wait_for_return:
            result=MyWS.do_wait_return({'type': 'wrj', 'commond': 'draw_fly_Cylinder', 'number': self.number,'points':points,'radius':radius,'high':high,'color':color,'alpha':alpha,'thickness':thickness,'time':time,'center':center})
            if result['result'] == ict_agent.core.SUCCESS:
                print("圆柱绘制完成")
        else:
            MyWS.do_immediately({'type': 'wrj', 'commond': 'draw_fly_Cylinder', 'number': self.number,'points':points,'radius':radius,'high':high,'color':color,'alpha':alpha,'thickness':thickness,'time':time,'center':center})
        return

    def draw_fly_Cone(self,center:[float,float,float],radius:float,high:float,numPoints:int,time:float,color: str = '#FFFFFF', alpha:float=1,thickness: float = 0.1,wait_for_return: bool = False):
        """
        画圆锥体(单无人机)
        :param center: 中心点
        :param radius: 圆锥半径
        :param high: 圆柱锥高度
        :param numPoints: 圆底的点数量（建议设置为4的倍数）
        :param time:绘制时长
        :param color: 颜色
        :param alpha: 透明度 (0-1)
        :param thickness: 线粗细
        :param wait_for_return: 是否阻塞，等待执绘制完成
        :return:
        """
        points=Math.drawCone(center,radius,high,numPoints)
        if wait_for_return:
            result=MyWS.do_wait_return({'type': 'wrj', 'commond': 'draw_fly_Cone', 'number': self.number, 'points': points, 'radius': radius,'high': high, 'color': color,'alpha':alpha, 'thickness': thickness, 'time': time, 'center': center})
            if result['result'] == ict_agent.core.SUCCESS:
                print("圆锥绘制完成")
        else:
            MyWS.do_immediately({'type': 'wrj', 'commond': 'draw_fly_Cone', 'number': self.number,'points':points,'radius':radius,'high':high,'color':color,'alpha':alpha,'thickness':thickness,'time':time,'center':center})
        return




from setuptools import setup

setup(
    name='ict_agent',
    version='1.0.10',
    authors='陈向学',
    description='智能ict三维编程拓展组件',
    packages=["ict_agent"],
    include_package_data=True,
    install_requires=[
        'websocket-client'
    ]
)